<?php

/**
 * @file
 * Contains Drupal\quote\Form\SettingsForm.
 */

namespace Drupal\quote\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class SettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'quote.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'quote_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('quote.settings');

    $form['modes'] = [
      '#type' => 'fieldset',
      '#title' => t('Select quote modes'),
    ];
    $form['modes']['quote_modes_quote_sel'] = [
      '#type' => 'checkbox',
      '#title' => t('Quote selected'),
      '#default_value' => $config->get('quote_modes_quote_sel'),
    ];
    $form['modes']['quote_modes_quote_all'] = [
      '#type' => 'checkbox',
      '#title' => t('Quote all'),
      '#default_value' => $config->get('quote_modes_quote_all'),
    ];
    $form['modes']['quote_modes_quote_reply_all'] = [
      '#type' => 'checkbox',
      '#title' => t('Quote and reply all'),
      '#default_value' => $config->get('quote_modes_quote_reply_all'),
    ];
    $form['modes']['quote_modes_quote_reply_sel'] = [
      '#type' => 'checkbox',
      '#title' => t('Quote and reply selected'),
      '#default_value' => $config->get('quote_modes_quote_reply_sel'),
      '#disabled' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('quote.settings')
      ->set('quote_modes_quote_sel', $form_state->getValue('quote_modes_quote_sel'))
      ->set('quote_modes_quote_all', $form_state->getValue('quote_modes_quote_all'))
      ->set('quote_modes_quote_reply_all', $form_state->getValue('quote_modes_quote_reply_all'))
      ->set('quote_modes_quote_reply_sel', $form_state->getValue('quote_modes_quote_reply_sel'))
      ->save();

    \Drupal::service('cache.render')->invalidateAll();
  }
}
